Custom arguments in NavVis SiteMaker let you fine‑tune post‑processing beyond the standard UI options. By adding validated command‑line flags, such as time-based trimming, cloud format selection, or pano/image controls, and you can precisely target what gets processed, how point clouds are generated, and which outputs are produced, all while overriding conflicting checkbox settings when needed.
Using Custom Arguments in SiteMaker
The Custom Arguments are located at the end of the Settings Tab.
.png?sv=2026-02-06&spr=https&st=2026-10-05T21%3A56%3A53Z&se=2026-10-05T22%3A15%3A53Z&sr=c&sp=r&sig=tSfx9wnmZf%2BXF0m0B4ZqTvjKVPA4r3eKAun%2FDXIDfsY%3D)
An example of using custom arguments to trim the processed dataset based on scan times:
--start-time=240 --stop-time=1250.png?sv=2026-02-06&spr=https&st=2026-10-05T21%3A56%3A53Z&se=2026-10-05T22%3A15%3A53Z&sr=c&sp=r&sig=tSfx9wnmZf%2BXF0m0B4ZqTvjKVPA4r3eKAun%2FDXIDfsY%3D)
Here, the processing starts from second 240 of the scan and ends at second 1250 of the scan.
There is a strict list of allowed custom arguments. You will find it in the last section of this page.
You can combine multiple custom arguments with spaces, as long as the arguments do not conflict with each other
For example:
--start-time=1250 --stop-time=240will not work.
Many custom arguments require input from the user:
A standalone argument, e.g.
--no-panoA numbered value needs to be defined by the user: e.g.
--start-time=240Choosing from a list of options: e.g.
--cloud-format=e57; here only a selection from {e57,pts,ptx,pcd,xyz,las,ply} is allowed
Adding Custom Arguments
If you need to use post-processing options that are not available in the settings directly, you can add custom arguments. Every custom argument entered is saved in the custom arguments (advanced) drop-down list, which can hold up to 15 different combinations.
Custom arguments override the settings in the other checkboxes if there is a contradiction.
To add custom arguments, do the following:
In NavVis SiteMaker, click the Settings tab.
Under the Advanced Settings section, from the Custom arguments (advanced) combination box, enter a custom argument, or click the drop-down list and select a previously entered and saved custom argument.
Press enter to apply the selection.
To see examples of custom arguments and their meanings, click the blue information button
.

List of Custom Arguments
A comprehensive list of custom arguments is accessible on any desktop equipped with SiteMaker. Open a terminal and enter the following command to get all arguments displayed:
navvis-postprocessing --helpNote: You can also process one or multiple data using commands in a terminal window. Examples appear at the end of the Help description.
A list of the Help description including all custom arguments for reference (Status v6.0.14, released in 2026):
***************************************************************************
Post-processing of NavVis datasets, (c) 2026 NavVis GmbH
***************************************************************************
usage: navvis-postprocessing [options] --proc-base-dir=<output> <input>
Post-processes datasets of NavVis mobile mapping systems.
For more information see the documentation at: https://knowledge.navvis.com/
or if you were unable to resolve your issue contact support@navvis.com
options:
-h, --help show this help message and exit
Standard arguments:
input List of recorded datasets, i.e. one or multiple dataset directories that should
be processed. May contain wildcards, e.g. "/my/data/datasets_rec/*" for
processing multiple datasets.
--proc-base-dir /path/to/datasets_proc
Base directory where sub-folders will be created for all output directories.
--start-time START_TIME
Start time defining from which point (in time) a dataset is meant to be
processed. The time must be specified either as the time in seconds relative to
the beginning of the dataset or as an absolute unix timestamp in seconds. The
time stamps are specific for each individual dataset.
--stop-time STOP_TIME
Stop time defining up to which point (in time) a dataset is meant to be
processed. The time must be specified either as the time in seconds relative to
the beginning of the dataset or as an absolute unix timestamp in seconds. The
time stamps are specific for each individual dataset.
Other:
--no-auto-transform Disables automatic transformation into the control point coordinate system.
This only has an impact if the option --use-anchors is specified. (default:
False)
--no-terminal-text-color, --no-color
Do not colorize text in terminal. (default: False)
SLAM:
--use-anchors If given will use anchor poses in rec dataset for post-processing if they are
present or use the file given with --anchor-poses (default: False)
--anchor-poses ANCHOR_POSES
If given in addition to --use-anchors, use anchor poses from provided file for
all datasets. File may be in anchor poses txt format or anchor poses csv format
--no-loop-closures If given, do not use loop closures in final optimization. (default: False)
Point cloud generation:
--res [0.005, 0.01, ... 0.2]
Sets the spatial resolution in [m] of the generated point cloud. (default: 0.01)
--preset {standard,outdoors,high-confidence}
Pointcloud settings which control which regions of the recorded data will
appear in final pointcloud (VLX/MLX only). Standard should give good results in
a wide range of scenarios. Outdoors gives more complete results in areas where
objects were only scanned sparsely and increases maximum range. High-confidence
will reduce the maximum range and keep only well scanned areas. This can be used
to remove unintentionally scanned regions and keep only the most accurately
scanned regions.
--dynamic-objects-filter-mode {disabled,balanced,aggressive}
Desired strength of dynamic object filtering from clouds. (default: balanced)
--max-laser-range MAX_LASER_RANGE
Sets the maximum range in [m] used to generate the point cloud. (default: 30.0)
--min-laser-range MIN_LASER_RANGE
Sets the minimum range in [m] used to generate the point cloud.
--cloud-format {e57,pts,ptx,pcd,xyz,las,ply} [{e57,pts,ptx,pcd,xyz,las,ply} ...]
Sets the desired pointcloud output format(s). Multiple values can be given if
more than one format is desired. (default: ['ply'])
--cloud-mode {sharp-edges, balanced, smooth-surfaces}
Controls the point cloud filtering mode. Only affects M6 datasets. See
https://docs.navvis.com/mapping/current/en/html/point_clouds/cloud_modes.html#bgk-cloud-mode
for details. (default: sharp-edges)
--store-raw-cloud Stores the raw point cloud along with the filtered one.Default: disabled for
VLX and MLX. (default: False)
Point cloud coloring:
--no-color-cloud Do not colorize the point cloud with RGB colors from images. Instead the cloud
will have lidar return intensities on the intensity channel. These are usually
shown as grayscale values in viewing applications. (default: False)
--coloring-output-type COLORING_OUTPUT_TYPE
Specifies the output type of the colored pointcloud.'rgbi' will store both RGB
values and intensity.'rgb' will store only RGB values. (default: rgbi)
--coloring-max-view-distance COLORING_MAX_VIEW_DISTANCE
Sets the maximum range for colorization as maximum distance from a point to a
camera. (default: 35.0)
Panorama Rendering:
--no-pano Do not render panoramic images. (default: False)
--mask-pano MASK_PANO
An optional "operator mask" to cut out the operator from the panoramic images.
If omitted, a default "operator mask" is computed internally and applied to the
panoramic images.
See the mapping documentation for how to create an operator mask.
--no-pano-floor-filling
Disable panoramic image floor filling. (default: False)
--num-threads-panos NUM_THREADS_PANOS
Set the number of rendered panoramas in parallel.
Allowed values: [1, 2, 3, ...].
Note: The maximum amount of rendered panoramas in parallel is limited by the
number of available system threads and the available/free system memory (RAM).
If omitted, the number of rendered panoramas in parallel is computed internally,
whereby the default number of parallel rendered panoramas is limited to 16.
Image Enhancement Options:
--image-preset {high-quality,fast,plain}
Preset for the post-processing of camera images. Possible values are:
'high-quality' results in the best image quality at the cost of a high runtime
'fast' results in good image quality with lowered runtime
'plain' disables most post-processing and leaves the images as-is
(default: high-quality)
Force Options:
--force, -f Force post-processing: Overwrite existing files/directories. (default: False)
--force-trajectories Deprecated. Same behavior as --force. (default: False)
--force-cloud Deprecated. Same behavior as --force. (default: False)
--force-color-cloud Deprecated. Same behavior as --force. (default: False)
--force-pano Deprecated. Same behavior as --force. (default: False)
Usage examples:
Process a single dataset:
navvis-postprocessing --proc-base-dir=/data/Project/datasets_proc /data/Project/datasets_rec/2014-11-23_14.48.37
Process multiple datasets, one after another:
navvis-postprocessing --proc-base-dir=/data/Project/datasets_proc /data/Project/datasets_rec/*
Process multiple datasets, one after another within a joint coordinate system with SLAM anchors:
navvis-postprocessing --proc-base-dir=/data/Project/datasets_proc /data/Project/datasets_rec/* --use-anchors --anchor-poses=/data/Project/my_anchor_poses.txt
Process a single dataset without panorama stitching:
navvis-postprocessing --no-pano --proc-base-dir=/data/Project/datasets_proc /data/Project/datasets_rec/2014-11-23_14.48.37
Force multiple datasets, overwrite existing data:
navvis-postprocessing --force --proc-base-dir=/data/Project/datasets_proc /data/Project/datasets_rec/*
Process multiple datasets and set desired number of panoramic images rendered in parallel:
navvis-postprocessing --num-threads-panos=4 --proc-base-dir=/data/Project/datasets_proc /data/Project/datasets_rec/*